Keep track of whether declararions were loaded from a precompiled
header or not via a new "PCHLevel" field in Decl. We currently use
this information to help CIndex filter out declarations that came from
a precompiled header (rather than from an AST file). Further down the
road, it can be used to help implement multi-level precompiled
headers.



git-svn-id: https://llvm.org/svn/llvm-project/cfe/trunk@84267 91177308-0d34-0410-b5e6-96231b3b80d8
diff --git a/test/Index/c-index-pch.c b/test/Index/c-index-pch.c
index 2298c8f..aae4eb3 100644
--- a/test/Index/c-index-pch.c
+++ b/test/Index/c-index-pch.c
@@ -1,7 +1,14 @@
 // RUN: clang-cc -emit-pch -x c -o %t.pch %S/c-index-pch.h &&
 // RUN: clang-cc -include-pch %t.pch -x c -emit-pch -o %t.ast %s &&
 // RUN: c-index-test %t.ast all | FileCheck -check-prefix=ALL %s
 // CHECK-ALL: FunctionDecl=foo
 // CHECK-ALL: VarDecl=bar
 // CHECK-ALL: FunctionDecl=wibble
 void wibble(int i);
+void wonka(float);
@@ -1,7 +1,14 @@
 // RUN: clang-cc -emit-pch -x c -o %t.pch %S/c-index-pch.h &&
 // RUN: clang-cc -include-pch %t.pch -x c -emit-pch -o %t.ast %s &&
-// RUN: c-index-test %t.ast all | FileCheck -check-prefix=ALL %s
-// CHECK-ALL: FunctionDecl=foo
-// CHECK-ALL: VarDecl=bar
-// CHECK-ALL: FunctionDecl=wibble
+// RUN: c-index-test %t.ast all | FileCheck -check-prefix=ALL %s &&
+// RUN: c-index-test %t.ast local | FileCheck -check-prefix=LOCAL %s
+// ALL: FunctionDecl=foo
+// ALL: VarDecl=bar
+// ALL: FunctionDecl=wibble
+// ALL: FunctionDecl=wonka
+// LOCAL-NOT: FunctionDecl=foo
+// LOCAL-NOT: VarDecl=bar
+// LOCAL: FunctionDecl=wibble
+// LOCAL: FunctionDecl=wonka
 void wibble(int i);